@@ -1,4 +1,4 @@
-package Mojo::File::ChangeNotify::WatcherProcess 0.01;
+package Mojo::File::ChangeNotify::WatcherProcess 0.02;
 use 5.020;
 use experimental 'signatures';
 use feature 'postderef';
@@ -31,7 +31,11 @@ sub watch( $subprocess, $args ) {
     my $watcher = File::ChangeNotify->instantiate_watcher( $args->%* );
     while( my @events = $watcher->wait_for_events ) {
         for my $list (@events) {
-            $subprocess->progress( [ map {; +{ path => $_->path, type => $_->type } } $list ]);
+            $subprocess->progress( [ map {;
+                                       defined $_->path
+                                       ? +{ path => $_->path, type => $_->type }
+                                       : ()
+                                     } $list ]);
         }
     }
 }
